import { getLabel, Label, PlatformPressable } from '@react-navigation/elements';
import { useTheme } from '@react-navigation/native';
import Color from 'color';
import React from 'react';
import { Platform, StyleSheet, View } from 'react-native';
import { TabBarIcon } from './TabBarIcon';
export function BottomTabItem({
  route,
  href,
  focused,
  descriptor,
  label,
  icon,
  badge,
  badgeStyle,
  button = props => /*#__PURE__*/React.createElement(PlatformPressable, props),
  accessibilityLabel,
  testID,
  onPress,
  onLongPress,
  horizontal,
  variant,
  activeTintColor: customActiveTintColor,
  inactiveTintColor: customInactiveTintColor,
  activeBackgroundColor = 'transparent',
  inactiveBackgroundColor = 'transparent',
  showLabel = true,
  allowFontScaling,
  labelStyle,
  iconStyle,
  style
}) {
  const {
    colors,
    fonts
  } = useTheme();
  const activeTintColor = customActiveTintColor === undefined ? colors.primary : customActiveTintColor;
  const inactiveTintColor = customInactiveTintColor === undefined ? Color(colors.text).mix(Color(colors.card), 0.5).hex() : customInactiveTintColor;
  const renderLabel = ({
    focused
  }) => {
    if (showLabel === false) {
      return null;
    }
    const color = focused ? activeTintColor : inactiveTintColor;
    if (typeof label !== 'string') {
      const {
        options
      } = descriptor;
      const children = getLabel({
        label: typeof options.tabBarLabel === 'string' ? options.tabBarLabel : undefined,
        title: options.title
      }, route.name);
      return label({
        focused,
        color,
        position: horizontal ? 'beside-icon' : 'below-icon',
        children
      });
    }
    return /*#__PURE__*/React.createElement(Label, {
      style: [horizontal ? [styles.labelBeside, {
        marginStart: icon !== undefined ? 16 : 0
      }, variant === 'uikit' && styles.labelBesideUikit] : styles.labelBeneath, variant === 'material' && fonts.medium, labelStyle],
      allowFontScaling: allowFontScaling,
      tintColor: color
    }, label);
  };
  const renderIcon = ({
    focused
  }) => {
    if (icon === undefined) {
      return null;
    }
    const activeOpacity = focused ? 1 : 0;
    const inactiveOpacity = focused ? 0 : 1;
    return /*#__PURE__*/React.createElement(TabBarIcon, {
      route: route,
      horizontal: horizontal,
      badge: badge,
      badgeStyle: badgeStyle,
      activeOpacity: activeOpacity,
      inactiveOpacity: inactiveOpacity,
      activeTintColor: activeTintColor,
      inactiveTintColor: inactiveTintColor,
      renderIcon: icon,
      style: iconStyle
    });
  };
  const scene = {
    route,
    focused
  };
  const backgroundColor = focused ? activeBackgroundColor : inactiveBackgroundColor;
  const {
    flex
  } = StyleSheet.flatten(style || {});
  const borderRadius = variant === 'material' ? horizontal ? 56 : 16 : 0;
  return /*#__PURE__*/React.createElement(View, {
    style: [
    // Clip ripple effect on Android
    {
      borderRadius,
      overflow: variant === 'material' ? 'hidden' : 'visible'
    }, style]
  }, button({
    href,
    onPress,
    onLongPress,
    testID,
    accessibilityLabel,
    // FIXME: accessibilityRole: 'tab' doesn't seem to work as expected on iOS
    accessibilityRole: Platform.select({
      ios: 'button',
      default: 'tab'
    }),
    accessibilityState: {
      selected: focused
    },
    // @ts-expect-error: keep for compatibility with older React Native versions
    accessibilityStates: focused ? ['selected'] : [],
    android_ripple: {
      borderless: true
    },
    hoverEffect: variant === 'material' ? {
      color: colors.text
    } : undefined,
    pressOpacity: 1,
    style: [styles.tab, {
      flex,
      backgroundColor,
      borderRadius
    }, horizontal ? [styles.tabHorizontal, variant === 'material' && styles.tabHorizontalMaterial] : [styles.tabVertical, variant === 'material' && styles.tabVerticalMaterial]],
    children: /*#__PURE__*/React.createElement(React.Fragment, null, renderIcon(scene), renderLabel(scene))
  }));
}
const styles = StyleSheet.create({
  tab: {
    alignItems: 'center',
    // Roundness for iPad hover effect
    borderRadius: 10
  },
  tabVertical: {
    justifyContent: 'flex-end',
    flexDirection: 'column'
  },
  tabVerticalMaterial: {
    padding: 10
  },
  tabHorizontal: {
    justifyContent: 'center',
    flexDirection: 'row',
    paddingVertical: 11,
    paddingStart: 16,
    paddingEnd: 24
  },
  tabHorizontalMaterial: {
    justifyContent: 'flex-start'
  },
  labelBeneath: {
    fontSize: 10
  },
  labelBeside: {
    marginEnd: 12,
    marginVertical: 4,
    lineHeight: 24,
    marginStart: 20
  },
  labelBesideUikit: {
    fontSize: 13
  }
});
//# sourceMappingURL=BottomTabItem.js.map